@@ -1,3 +1,7 @@
+#Enable when we drop 3.6
+#from __future__ import annotations
+from typing import List, Optional
+
 import io, logging, pyarrow as pa, requests, sys
 from .ArrowFileUploader import ArrowFileUploader
 
@@ -306,12 +310,8 @@ class ArrowUploader:
 
     def post(self, as_files: bool = True, memoize: bool = True):
         """
-            as_files deprecation plan:
-                Graphistry 2.34: Introduced
-                Graphistry 2.35: Does nothing (runtime warning); all uploads are Files
-                Graphistry 2.36: Remove flag
+        Note: likely want to pair with self.maybe_post_share_link(g)
         """
-
         if as_files:
 
             file_uploader = ArrowFileUploader(self)
@@ -348,6 +348,98 @@ class ArrowUploader:
         
         return self
 
+
+    ###########################################
+
+
+    def cascade_privacy_settings(
+        self,
+        mode: Optional[str] = None,
+        notify: Optional[bool] = None,
+        invited_users: Optional[List] = None,
+        message: Optional[str] = None
+    ):
+        """
+        Cascade:
+            - local (passed in)
+            - global
+            - hard-coded
+        """
+
+        from .pygraphistry import PyGraphistry
+        global_privacy = PyGraphistry._config['privacy']
+        if global_privacy is not None:
+            if mode is None:
+                mode = global_privacy['mode']
+            if notify is None:
+                notify = global_privacy['notify']
+            if invited_users is None:
+                invited_users = global_privacy['invited_users']
+            if message is None:
+                message = global_privacy['message']
+
+        if mode is None:
+            mode = 'private'
+        if notify is None:
+            notify = False
+        if invited_users is None:
+            invited_users = []
+        if message is None:
+            message = ''
+
+        return mode, notify, invited_users, message
+
+
+    def post_share_link(
+        self,
+        obj_pk: str,
+        obj_type: str = 'dataset',
+        privacy: Optional[dict] = None
+    ):
+        """
+        Set sharing settings. Any settings not passed here will cascade from PyGraphistry or defaults
+        """
+
+        mode, notify, invited_users, message = self.cascade_privacy_settings(**(privacy or {}))
+
+        path = self.server_base_path + '/api/v2/share/link/'
+        tok = self.token
+        res = requests.post(
+            path,
+            verify=self.certificate_validation,
+            headers={'Authorization': f'Bearer {tok}'},
+            json={
+                'obj_pk': obj_pk,
+                'obj_type': obj_type,
+                'mode': mode,
+                'notify': notify,
+                'invited_users': invited_users,
+                'message': message
+            })
+
+        if res.status_code != requests.codes.ok:
+            logger.error('Failed setting sharing status (code %s): %s', res.status_code, res.text, exc_info=True)
+
+        if res.status_code == 404:
+            raise Exception(f'Code not find resource {path}; is your server location correct and does it support sharing?')
+
+        if res.status_code == 403:
+            raise Exception(f'Permission denied ({path}); do you have edit access and does your account having sharing enabled?')
+
+        try:
+            out = res.json()
+            logger.debug('Server create file response: %s', out)
+            if res.status_code != requests.codes.ok:
+                res.raise_for_status()
+        except Exception as e:
+            logger.error('Unexpected error setting sharing settings: %s', res.text, exc_info=True)
+            raise e
+
+        logger.debug('Set privacy: mode %s, notify %s, users %s, message: %s', mode, notify, invited_users, message)
+        
+        return out
+
+
     ###########################################
 
 
@@ -373,6 +465,11 @@ class ArrowUploader:
             if not ('success' in out) or not out['success']:
                 raise Exception('No success indicator in server response')
             return out
+        except requests.exceptions.HTTPError as e:
+            logger.error('Failed to post arrow to %s (%s)', sub_path, e.request.url, exc_info=True)
+            logger.error('%s', e)
+            logger.error('%s', e.response.text)
+            raise e
         except Exception as e:
             logger.error('Failed to post arrow to %s', sub_path, exc_info=True)
             raise e
@@ -398,7 +495,25 @@ class ArrowUploader:
     ###########################################
 
 
+    #TODO refactor to be part of post()
+    def maybe_post_share_link(self, g) -> bool:
+        """
+            Skip if never called .privacy()
+            Return True/False based on whether called
+        """
+        from .pygraphistry import PyGraphistry
+        logger.debug('Privacy: global (%s), local (%s)', PyGraphistry._config['privacy'] or 'None', g._privacy or 'None')
+        if PyGraphistry._config['privacy'] is not None or g._privacy is not None:
+            self.post_share_link(self.dataset_id, 'dataset', g._privacy)
+            return True
+
+        return False
+
+
     def post_g(self, g, name=None, description=None):
+        """
+        Warning: main post() does not call this
+        """
 
         self.edge_encodings = self.g_to_edge_encodings(g)
         self.node_encodings = self.g_to_node_encodings(g)
@@ -411,7 +526,10 @@ class ArrowUploader:
         if not (g._nodes is None):
             self.nodes = pa.Table.from_pandas(g._nodes, preserve_index=False).replace_schema_metadata({})
 
-        return self.post()
+        out = self.post()
+        self.maybe_post_share_link(g)
+
+        return out
     
     def post_edges_file(self, file_path, file_type='csv'):
         return self.post_file(file_path, 'edges', file_type)
